@@ -79,10 +79,10 @@ AutoDetailsView::AutoDetailsView(AutoProjectWidget* widget, AutoProjectPart* par
 	buildTargetAction->setEnabled( false );
 	executeTargetAction->setEnabled( false );
 	removeDetailAction->setEnabled(false);
-	connect( m_listView, TQT_SIGNAL( selectionChanged( TQListViewItem* ) ),
-	         this, TQT_SLOT( slotSelectionChanged( TQListViewItem* ) ) );
-	connect( m_listView, TQT_SIGNAL( selectionChanged() ),
-	         this, TQT_SLOT( slotSelectionChanged( ) ) );
+	connect( m_listView, TQ_SIGNAL( selectionChanged( TQListViewItem* ) ),
+	         this, TQ_SLOT( slotSelectionChanged( TQListViewItem* ) ) );
+	connect( m_listView, TQ_SIGNAL( selectionChanged() ),
+	         this, TQ_SLOT( slotSelectionChanged( ) ) );
 }
 
 
@@ -177,7 +177,7 @@ void AutoDetailsView::initActions()
 	TDEActionCollection * actions = new TDEActionCollection( this );
 
 	targetOptionsAction = new AutoToolsAction( i18n( "Options..." ), "configure", 0,
-	                                           TQT_TQOBJECT(this), TQT_SLOT( slotTargetOptions() ), actions,
+	                                           this, TQ_SLOT( slotTargetOptions() ), actions,
 	                                   "target options" );
 	targetOptionsAction->setWhatsThis(i18n("<b>Options</b><p>Target options dialog that "
 	                                       "provides settings for linker flags and lists "
@@ -188,7 +188,7 @@ void AutoDetailsView::initActions()
 
 	TQToolTip::add( m_button1, tr2i18n( "Create New File..." ) );
 	addNewFileAction = new AutoToolsAction( i18n( "Create New File..." ), "document-new", 0,
-	                                        TQT_TQOBJECT(this), TQT_SLOT( slotAddNewFile() ), actions,
+	                                        this, TQ_SLOT( slotAddNewFile() ), actions,
 	                                "add new file" );
 	addNewFileAction->setWhatsThis(i18n("<b>Create new file</b><p>Creates a new file and "
 	                                    "adds it to a currently selected target."));
@@ -197,7 +197,7 @@ void AutoDetailsView::initActions()
 
 	TQToolTip::add( m_button2, tr2i18n( "Add Existing Files..." ) );
 	addExistingFileAction = new AutoToolsAction( i18n( "Add Existing Files..." ), "fileimport", 0,
-	                                             TQT_TQOBJECT(this), TQT_SLOT( slotAddExistingFile() ), actions,
+	                                             this, TQ_SLOT( slotAddExistingFile() ), actions,
 	                                     "add existing file" );
 	addExistingFileAction->setWhatsThis(i18n("<b>Add existing files</b><p>Adds existing "
 	                                         "file to a currently selected target. Header "
@@ -208,12 +208,12 @@ void AutoDetailsView::initActions()
 	addExistingFileAction->setEnabled( false );
 
 	addIconAction = new TDEAction( i18n( "Add Icon..." ), "iconadd_tdevelop", 0,
-	                             TQT_TQOBJECT(this), TQT_SLOT( slotAddIcon() ), actions, "add icon" );
+	                             this, TQ_SLOT( slotAddIcon() ), actions, "add icon" );
 	addIconAction->setWhatsThis(i18n("<b>Add icon</b><p>Adds an icon to a KDEICON target."));
 
 	TQToolTip::add( m_button4, tr2i18n( "Build Target"));
 	buildTargetAction = new AutoToolsAction( i18n( "Build Target..." ), "launch", 0,
-	                                         TQT_TQOBJECT(this), TQT_SLOT( slotBuildTarget() ), actions,
+	                                         this, TQ_SLOT( slotBuildTarget() ), actions,
 	                                 "build target" );
 	buildTargetAction->setWhatsThis(i18n("<b>Build target</b><p>Constructs a series of "
 	                                     "make commands to build the selected target. "
@@ -223,7 +223,7 @@ void AutoDetailsView::initActions()
 
 	TQToolTip::add( m_button5, tr2i18n( "Execute Target..."));
 	executeTargetAction = new AutoToolsAction( i18n( "Execute Target..." ), "application-x-executable", 0,
-	                                           TQT_TQOBJECT(this), TQT_SLOT( slotExecuteTarget() ), actions,
+	                                           this, TQ_SLOT( slotExecuteTarget() ), actions,
 	                                   "execute target" );
 	executeTargetAction->setWhatsThis(i18n("<b>Execute target</b><p>Executes the target "
 	                                       "and tries to build in case it is not built."));
@@ -231,7 +231,7 @@ void AutoDetailsView::initActions()
 	executeTargetAction->setEnabled( false );
 
 	setActiveTargetAction = new TDEAction( i18n( "Make Target Active" ), "", 0,
-	                                     TQT_TQOBJECT(this), TQT_SLOT( slotSetActiveTarget() ), actions,
+	                                     this, TQ_SLOT( slotSetActiveTarget() ), actions,
 	                                     "set active target" );
 	setActiveTargetAction->setWhatsThis(i18n("<b>Make target active</b><p>Marks the "
 	                                         "currently selected target as 'active'. New "
@@ -241,8 +241,8 @@ void AutoDetailsView::initActions()
 	                                         "command builds it."));
 
 	TQToolTip::add( m_button3, tr2i18n( "Remove"));
-	removeDetailAction = new AutoToolsAction( i18n( "Remove" ), "edit-delete", 0, TQT_TQOBJECT(this),
-	                                  TQT_SLOT( slotRemoveDetail() ), actions,
+	removeDetailAction = new AutoToolsAction( i18n( "Remove" ), "edit-delete", 0, this,
+	                                  TQ_SLOT( slotRemoveDetail() ), actions,
 	                                  "remove detail" );
 	removeDetailAction->setWhatsThis(i18n("<b>Remove</b><p>Shows a list of targets "
 	                                      "dependent on the selected target or file and "
@@ -251,12 +251,12 @@ void AutoDetailsView::initActions()
 	removeDetailAction->plug( m_button3 );
 	removeDetailAction->setEnabled( false );
 
-	connect( m_listView, TQT_SIGNAL( executed( TQListViewItem* ) ),
-	         this, TQT_SLOT( slotDetailsExecuted( TQListViewItem* ) ) );
-	connect( m_listView, TQT_SIGNAL( returnPressed( TQListViewItem* ) ),
-	         this, TQT_SLOT( slotDetailsExecuted( TQListViewItem* ) ) );
-	connect( m_listView, TQT_SIGNAL( contextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ),
-	         this, TQT_SLOT( slotDetailsContextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ) );
+	connect( m_listView, TQ_SIGNAL( executed( TQListViewItem* ) ),
+	         this, TQ_SLOT( slotDetailsExecuted( TQListViewItem* ) ) );
+	connect( m_listView, TQ_SIGNAL( returnPressed( TQListViewItem* ) ),
+	         this, TQ_SLOT( slotDetailsExecuted( TQListViewItem* ) ) );
+	connect( m_listView, TQ_SIGNAL( contextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ),
+	         this, TQ_SLOT( slotDetailsContextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ) );
 }
 
 TQString AutoDetailsView::getUiFileLink(const TQString& relpath, const TQString& filename)
