@@ -124,7 +124,7 @@ void Layout::setup()
     // we leave here.
     if ( !lastList || ( lastList->count() < 2 &&
 			( !layoutBase ||
-			  ( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( TQT_TQOBJECT(layoutBase) ) ) ) &&
+			  ( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( layoutBase ) ) ) &&
 			    layoutBase != formWindow->mainContainer() ) )
 			) ) {
 	widgets.clear();
@@ -142,8 +142,8 @@ void Layout::setup()
     // widgets to get informed if one gets deleted to be able to
     // handle that and do not crash in this case
     for ( w = widgets.first(); w; w = widgets.next() ) {
-	connect( w, TQT_SIGNAL( destroyed() ),
-		 this, TQT_SLOT( widgetDestroyed() ) );
+	connect( w, TQ_SIGNAL( destroyed() ),
+		 this, TQ_SLOT( widgetDestroyed() ) );
 	startPoint = TQPoint( TQMIN( startPoint.x(), w->x() ),
 			     TQMIN( startPoint.y(), w->y() ) );
 	geometries.insert( w, TQRect( w->pos(), w->size() ) );
@@ -167,7 +167,7 @@ bool Layout::prepareLayout( bool &needMove, bool &needReparent )
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() )
 	w->raise();
     needMove = !layoutBase;
-    needReparent = needMove || ::tqqt_cast<TQLayoutWidget*>(layoutBase) || ::tqqt_cast<TQSplitter*>(layoutBase);
+    needReparent = needMove || ::tqt_cast<TQLayoutWidget*>(layoutBase) || ::tqt_cast<TQSplitter*>(layoutBase);
     if ( !layoutBase ) {
 	if ( !useSplitter )
 	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQLayoutWidget" ),
@@ -195,7 +195,7 @@ void Layout::finishLayout( bool needMove, TQLayout *layout )
     layoutBase->show();
     layout->activate();
     formWindow->insertWidget( layoutBase );
-    formWindow->selectWidget( TQT_TQOBJECT(layoutBase) );
+    formWindow->selectWidget( layoutBase );
     TQString n = layoutBase->name();
     if ( n.find( "qt_dead_widget_" ) != -1 ) {
 	n.remove( 0, TQString( "qt_dead_widget_" ).length() );
@@ -214,9 +214,9 @@ void Layout::undoLayout()
 	it.key()->reparent( WidgetFactory::containerOfWidget( parent ), 0, ( *it ).topLeft(), it.key()->isVisibleTo( formWindow ) );
 	it.key()->resize( ( *it ).size() );
     }
-    formWindow->selectWidget( TQT_TQOBJECT(layoutBase), FALSE );
+    formWindow->selectWidget( layoutBase, FALSE );
     WidgetFactory::deleteLayout( layoutBase );
-    if ( parent != layoutBase && !::tqqt_cast<TQMainWindow*>(layoutBase) ) {
+    if ( parent != layoutBase && !::tqt_cast<TQMainWindow*>(layoutBase) ) {
 	layoutBase->hide();
 	TQString n = layoutBase->name();
 	n.prepend( "qt_dead_widget_" );
@@ -225,9 +225,9 @@ void Layout::undoLayout()
 	layoutBase->setGeometry( oldGeometry );
     }
     if ( widgets.first() )
-	formWindow->selectWidget( TQT_TQOBJECT(widgets.first()) );
+	formWindow->selectWidget( widgets.first() );
     else
-	formWindow->selectWidget( TQT_TQOBJECT(formWindow) );
+	formWindow->selectWidget( formWindow );
 }
 
 void Layout::breakLayout()
@@ -241,7 +241,7 @@ void Layout::breakLayout()
     WidgetFactory::deleteLayout( layoutBase );
     bool needReparent = qstrcmp( layoutBase->className(), "TQLayoutWidget" ) == 0 ||
 			qstrcmp( layoutBase->className(), "TQSplitter" ) == 0 ||
-			( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( TQT_TQOBJECT(layoutBase) ) ) ) &&
+			( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( layoutBase ) ) ) &&
 			  layoutBase != formWindow->mainContainer() );
     bool needResize = qstrcmp( layoutBase->className(), "TQSplitter" ) == 0;
     bool add = geometries.isEmpty();
@@ -267,9 +267,9 @@ void Layout::breakLayout()
 	parent = layoutBase;
     }
     if ( widgets.first() && widgets.first()->isVisibleTo( formWindow ) )
-	formWindow->selectWidget( TQT_TQOBJECT(widgets.first()) );
+	formWindow->selectWidget( widgets.first() );
     else
-	formWindow->selectWidget( TQT_TQOBJECT(formWindow) );
+	formWindow->selectWidget( formWindow );
 }
 
 class HorizontalLayoutList : public TQWidgetList
@@ -321,14 +321,14 @@ void HorizontalLayout::doLayout()
 		layout->addWidget( w, 0, ( (Spacer*)w )->alignment() );
 	    else
 		layout->addWidget( w );
-	    if ( ::tqqt_cast<TQLayoutWidget*>(w) )
+	    if ( ::tqt_cast<TQLayoutWidget*>(w) )
 		( (TQLayoutWidget*)w )->updateSizePolicy();
 	}
 	w->show();
     }
 
-    if ( ::tqqt_cast<TQSplitter*>(layoutBase) )
-	( (TQSplitter*)layoutBase )->setOrientation( Qt::Horizontal );
+    if ( ::tqt_cast<TQSplitter*>(layoutBase) )
+	( (TQSplitter*)layoutBase )->setOrientation( TQt::Horizontal );
 
     finishLayout( needMove, layout );
 }
@@ -385,14 +385,14 @@ void VerticalLayout::doLayout()
 		layout->addWidget( w, 0, ( (Spacer*)w )->alignment() );
 	    else
 		layout->addWidget( w );
-	    if ( ::tqqt_cast<TQLayoutWidget*>(w) )
+	    if ( ::tqt_cast<TQLayoutWidget*>(w) )
 		( (TQLayoutWidget*)w )->updateSizePolicy();
 	}
 	w->show();
     }
 
-    if ( ::tqqt_cast<TQSplitter*>(layoutBase) )
-	( (TQSplitter*)layoutBase )->setOrientation( Qt::Vertical );
+    if ( ::tqt_cast<TQSplitter*>(layoutBase) )
+	( (TQSplitter*)layoutBase )->setOrientation( TQt::Vertical );
 
     finishLayout( needMove, layout );
 }
@@ -759,11 +759,11 @@ void GridLayout::doLayout()
 	    if ( needReparent && w->parent() != layoutBase )
 		w->reparent( layoutBase, 0, TQPoint( 0, 0 ), FALSE );
 	    if ( rs * cs == 1 ) {
-		layout->addWidget( w, r, c, ::tqqt_cast<Spacer*>(w) ? ( (Spacer*)w )->alignment() : 0 );
+		layout->addWidget( w, r, c, ::tqt_cast<Spacer*>(w) ? ( (Spacer*)w )->alignment() : 0 );
 	    } else {
-		layout->addMultiCellWidget( w, r, r+rs-1, c, c+cs-1, ::tqqt_cast<Spacer*>(w) ? ( (Spacer*)w )->alignment() : 0 );
+		layout->addMultiCellWidget( w, r, r+rs-1, c, c+cs-1, ::tqt_cast<Spacer*>(w) ? ( (Spacer*)w )->alignment() : 0 );
 	    }
-	    if ( ::tqqt_cast<TQLayoutWidget*>(w) )
+	    if ( ::tqt_cast<TQLayoutWidget*>(w) )
 		( (TQLayoutWidget*)w )->updateSizePolicy();
 	    w->show();
 	} else {
@@ -865,7 +865,7 @@ void GridLayout::buildGrid()
 
 Spacer::Spacer( TQWidget *parent, const char *name )
     : TQWidget( parent, name, WMouseNoMask ),
-      orient(Qt::Vertical ), interactive(TRUE), sh( TQSize(20,20) )
+      orient(TQt::Vertical ), interactive(TRUE), sh( TQSize(20,20) )
 {
     setSizeType( Expanding );
     setAutoMask( TRUE );
@@ -876,7 +876,7 @@ void Spacer::paintEvent( TQPaintEvent * )
     TQPainter p( this );
     p.setPen( TQt::blue );
 
-    if ( orient ==Qt::Horizontal ) {
+    if ( orient ==TQt::Horizontal ) {
 	const int dist = 3;
 	const int amplitude = TQMIN( 3, height() / 3 );
 	const int base = height() / 2;
@@ -915,7 +915,7 @@ void Spacer::resizeEvent( TQResizeEvent* e)
 void Spacer::updateMask()
 {
     TQRegion r( rect() );
-    if ( orient ==Qt::Horizontal ) {
+    if ( orient ==TQt::Horizontal ) {
 	const int amplitude = TQMIN( 3, height() / 3 );
 	const int base = height() / 2;
 	r = r.subtract( TQRect(1, 0, width() - 2, base - amplitude ) );
@@ -932,7 +932,7 @@ void Spacer::updateMask()
 void Spacer::setSizeType( SizeType t )
 {
     TQSizePolicy sizeP;
-    if ( orient ==Qt::Vertical )
+    if ( orient ==TQt::Vertical )
 	sizeP = TQSizePolicy( TQSizePolicy::Minimum, (TQSizePolicy::SizeType)t );
     else
 	sizeP = TQSizePolicy( (TQSizePolicy::SizeType)t, TQSizePolicy::Minimum );
@@ -942,14 +942,14 @@ void Spacer::setSizeType( SizeType t )
 
 Spacer::SizeType Spacer::sizeType() const
 {
-    if ( orient ==Qt::Vertical )
+    if ( orient ==TQt::Vertical )
 	return (SizeType)sizePolicy().verData();
     return (SizeType)sizePolicy().horData();
 }
 
 int Spacer::alignment() const
 {
-    if ( orient ==Qt::Vertical )
+    if ( orient ==TQt::Vertical )
 	return AlignHCenter;
     return AlignVCenter;
 }
@@ -958,7 +958,7 @@ TQSize Spacer::minimumSize() const
 {
     TQSize s = TQSize( 20,20 );
     if ( sizeType() == Expanding )
-	if ( orient ==Qt::Vertical )
+	if ( orient ==TQt::Vertical )
 	    s.rheight() = 0;
 	else
 	    s.rwidth() = 0;
@@ -979,12 +979,12 @@ void Spacer::setSizeHint( const TQSize &s )
     updateGeometry();
 }
 
-Qt::Orientation Spacer::orientation() const
+TQt::Orientation Spacer::orientation() const
 {
     return orient;
 }
 
-void Spacer::setOrientation( Qt::Orientation o )
+void Spacer::setOrientation( TQt::Orientation o )
 {
     if ( orient == o )
 	return;
