@@ -49,7 +49,7 @@
 ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw )
     : ListViewEditorBase( parent, 0, TRUE ), listview( lv ), formwindow( fw )
 {
-    connect( helpButton, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
+    connect( helpButton, TQ_SIGNAL( clicked() ), MainWindow::self, TQ_SLOT( showDialogHelp() ) );
     itemText->setEnabled( FALSE );
     itemChoosePixmap->setEnabled( FALSE );
     itemDeletePixmap->setEnabled( FALSE );
@@ -71,8 +71,8 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
     // Clamp on drag and drop to TQListView
     ListViewDnd *itemsDnd = new ListViewDnd( itemsPreview );
     itemsDnd->setDragMode( ListViewDnd::Internal | ListViewDnd::Move );
-    TQObject::connect( itemsDnd, TQT_SIGNAL( dropped( TQListViewItem * ) ),
-		      itemsDnd, TQT_SLOT( confirmDrop( TQListViewItem * ) ) );
+    TQObject::connect( itemsDnd, TQ_SIGNAL( dropped( TQListViewItem * ) ),
+		      itemsDnd, TQ_SLOT( confirmDrop( TQListViewItem * ) ) );
 
     // Enable rename for all TQListViewItems
     TQListViewItemIterator it = ((TQListView *)itemsPreview)->firstChild();
@@ -81,9 +81,9 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
 
     // Connect listview signal to signal-relay
     TQObject::connect( itemsPreview,
-		      TQT_SIGNAL( itemRenamed( TQListViewItem*, int, const TQString & ) ),
+		      TQ_SIGNAL( itemRenamed( TQListViewItem*, int, const TQString & ) ),
 		      this,
-		      TQT_SLOT( emitItemRenamed(TQListViewItem*, int, const TQString&) ) );
+		      TQ_SLOT( emitItemRenamed(TQListViewItem*, int, const TQString&) ) );
 
     // Connect signal-relay to TQLineEdit "itemText"
     TQObjectList *l = parent->queryList( "TQLineEdit", "itemText" );
@@ -92,24 +92,24 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
     while ( (obj = itemsLineEditIt.current()) != 0 ) {
         ++itemsLineEditIt;
 	TQObject::connect( this,
-			  TQT_SIGNAL( itemRenamed( const TQString & ) ),
+			  TQ_SIGNAL( itemRenamed( const TQString & ) ),
 			  obj,
-			  TQT_SLOT( setText( const TQString & ) ) );
+			  TQ_SLOT( setText( const TQString & ) ) );
     }
     delete l;
 
     // Clamp on drag and drop to TQListBox
     ListBoxDnd *columnsDnd = new ListBoxDnd( colPreview );
     columnsDnd->setDragMode( ListBoxDnd::Internal | ListBoxDnd::Move );
-    TQObject::connect( columnsDnd, TQT_SIGNAL( dropped( TQListBoxItem * ) ),
-		      columnsDnd, TQT_SLOT( confirmDrop( TQListBoxItem * ) ) );
+    TQObject::connect( columnsDnd, TQ_SIGNAL( dropped( TQListBoxItem * ) ),
+		      columnsDnd, TQ_SLOT( confirmDrop( TQListBoxItem * ) ) );
 
     // Clamp on rename to TQListBox
     ListBoxRename *columnsRename = new ListBoxRename( colPreview );
     TQObject::connect( columnsRename,
-		      TQT_SIGNAL( itemTextChanged( const TQString & ) ),
+		      TQ_SIGNAL( itemTextChanged( const TQString & ) ),
 		      this,
-		      TQT_SLOT( columnTextChanged( const TQString & ) ) );
+		      TQ_SLOT( columnTextChanged( const TQString & ) ) );
 
     // Find TQLineEdit "colText" and connect
     l = parent->queryList( "TQLineEdit", "colText" );
@@ -117,9 +117,9 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
     while ( (obj = columnsLineEditIt.current()) != 0 ) {
         ++columnsLineEditIt;
 	TQObject::connect( columnsRename,
-			  TQT_SIGNAL( itemTextChanged( const TQString & ) ),
+			  TQ_SIGNAL( itemTextChanged( const TQString & ) ),
 			  obj,
-			  TQT_SLOT( setText( const TQString & ) ) );
+			  TQ_SLOT( setText( const TQString & ) ) );
     }
     delete l;
 }
