@@ -80,7 +80,7 @@ CvsServicePartImpl::CvsServicePartImpl( CvsServicePart *part, const char *name )
         m_scheduler = new DirectScheduler( m_widget );
         m_fileInfoProvider = new CVSFileInfoProvider( part, m_cvsService );
     
-        connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(slotProjectOpened()) );
+        connect( core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(slotProjectOpened()) );
     }
     else
     {
@@ -374,7 +374,7 @@ bool CvsServicePartImpl::checkout()
 			modulePath = dlg.workDir() + dlg.module();
 
         	m_scheduler->schedule( job );
-        	connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)), this, TQT_SLOT(slotCheckoutFinished(bool,int)) );
+        	connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)), this, TQ_SLOT(slotCheckoutFinished(bool,int)) );
 			return true;
 		}
     }
@@ -406,7 +406,7 @@ void CvsServicePartImpl::commit( const KURL::List& urlList )
     }
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)), this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)), this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     // 2. if requested to do so, add an entry to the Changelog too
     if (dlg.mustAddToChangeLog())
@@ -448,7 +448,7 @@ void CvsServicePartImpl::update( const KURL::List& urlList )
         additionalOptions );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)), this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)), this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -465,7 +465,7 @@ void CvsServicePartImpl::add( const KURL::List& urlList, bool binary )
     DCOPRef cvsJob = m_cvsService->add( fileList(), binary );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)), this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)), this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -531,7 +531,7 @@ void CvsServicePartImpl::unedit( const KURL::List& urlList)
     DCOPRef cvsJob = m_cvsService->unedit( fileList() );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)), this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)), this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -548,7 +548,7 @@ void CvsServicePartImpl::edit( const KURL::List& urlList)
     DCOPRef cvsJob = m_cvsService->edit( fileList() );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)), this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)), this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -582,8 +582,8 @@ void CvsServicePartImpl::remove( const KURL::List& urlList )
     DCOPRef cvsJob = m_cvsService->remove( fileList(), true );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)),
-        this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)),
+        this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -606,8 +606,8 @@ void CvsServicePartImpl::removeStickyFlag( const KURL::List& urlList )
         "-A" );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)),
-        this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)),
+        this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -656,8 +656,8 @@ void CvsServicePartImpl::diff( const KURL::List& urlList )
     }
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)),
-        this, TQT_SLOT(slotDiffFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)),
+        this, TQ_SLOT(slotDiffFinished(bool,int)) );
 
     doneOperation();
 }
@@ -680,8 +680,8 @@ void CvsServicePartImpl::tag( const KURL::List& urlList )
         dlg.isBranch(), dlg.force() );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)),
-        this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)),
+        this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -705,8 +705,8 @@ void CvsServicePartImpl::unTag( const KURL::List& urlList )
         dlg.isBranch(), dlg.force() );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)),
-        this, TQT_SLOT(slotJobFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)),
+        this, TQ_SLOT(slotJobFinished(bool,int)) );
 
     doneOperation();
 }
@@ -747,7 +747,7 @@ void CvsServicePartImpl::createNewProject( const TQString &dirName,
 	DCOPRef cvsJob = m_cvsService->import( dirName, location, module, filesToIgnore, message, vendor, release, false );
 
     m_scheduler->schedule( cvsJob );
-    connect( processWidget(), TQT_SIGNAL(jobFinished(bool,int)), this, TQT_SLOT(slotCheckoutFinished(bool,int)) );
+    connect( processWidget(), TQ_SIGNAL(jobFinished(bool,int)), this, TQ_SLOT(slotCheckoutFinished(bool,int)) );
 */
 	TQString rsh_preamble;
     if ( !options->cvsRshEnvVar().isEmpty() )
