@@ -44,7 +44,7 @@ SvnLogViewWidget::SvnLogViewWidget(subversionPart *part, TQWidget *parent)
     m_layout = new TQGridLayout( this, 1, 1, 11, 6, "SvnLogViewWidgetBaseLayout");
 
     splitter1 = new TQSplitter( this, "splitter1" );
-    splitter1->setOrientation( Qt::Horizontal );
+    splitter1->setOrientation( TQt::Horizontal );
     splitter1->setMargin(1);
 
     listView1 = new TQListView( splitter1, "listView1" );
@@ -73,9 +73,9 @@ SvnLogViewWidget::SvnLogViewWidget(subversionPart *part, TQWidget *parent)
     resize( TQSize(692, 343).expandedTo(minimumSizeHint()) );
     clearWState( WState_Polished );
     
-	connect( listView1, TQT_SIGNAL(clicked( TQListViewItem *)), this, TQT_SLOT(slotClicked(TQListViewItem*)) );
-    connect( listView1, TQT_SIGNAL(contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
-             this, TQT_SLOT(contextMenuRequested(TQListViewItem*, const TQPoint&, int)) );
+	connect( listView1, TQ_SIGNAL(clicked( TQListViewItem *)), this, TQ_SLOT(slotClicked(TQListViewItem*)) );
+    connect( listView1, TQ_SIGNAL(contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
+             this, TQ_SLOT(contextMenuRequested(TQListViewItem*, const TQPoint&, int)) );
 }
 SvnLogViewWidget::~SvnLogViewWidget()
 {
@@ -128,8 +128,8 @@ void SvnLogViewWidget::contextMenuRequested( TQListViewItem *item, const TQPoint
     if( !m_ctxLogItem )
         return;
     TQPopupMenu *menu = new TQPopupMenu(this);
-    menu->insertItem( i18n("Blame this revision"), this, TQT_SLOT(blameThis()) );
-    menu->insertItem( i18n("Difference to previous revision"), this, TQT_SLOT(diffToPrevious()) );
+    menu->insertItem( i18n("Blame this revision"), this, TQ_SLOT(blameThis()) );
+    menu->insertItem( i18n("Difference to previous revision"), this, TQ_SLOT(diffToPrevious()) );
     menu->exec( pos );
 }
 void SvnLogViewWidget::blameThis()
@@ -195,10 +195,10 @@ SvnLogViewOptionDlg::SvnLogViewOptionDlg( TQWidget *parent, const char* name, bo
 	radio4->setChecked(true); //start revistion by revision keyword
 	radio5->setChecked(true); //end revision by revision number
 	reinstallRevisionSpecifiers();
-	connect( intInput1, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setStartRevnumRadio()) );
-	connect( comboBox1, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(setStartRevkindRadio()) );
-	connect( intInput2, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setEndRevnumRadio()) );
-	connect( comboBox2, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(setEndRevkindRadio()) );
+	connect( intInput1, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setStartRevnumRadio()) );
+	connect( comboBox1, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(setStartRevkindRadio()) );
+	connect( intInput2, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setEndRevnumRadio()) );
+	connect( comboBox2, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(setEndRevkindRadio()) );
 }
 SvnLogViewOptionDlg::~SvnLogViewOptionDlg()
 {}
